@@ -2,7 +2,7 @@ package Dist::Zilla::PluginBundle::Author::DOHERTY;
 # ABSTRACT: configure Dist::Zilla like DOHERTY
 use strict;
 use warnings;
-our $VERSION = '0.27'; # VERSION
+our $VERSION = '0.28'; # VERSION
 
 
 # Dependencies
@@ -51,6 +51,7 @@ sub configure {
         # Version number
         [ 'Git::NextVersion' => { version_regexp => $conf->{version_regexp} } ],
         'OurPkgVersion',
+        'Git::Describe',
 
         # Gather & prune
         'GatherDir',
@@ -136,7 +137,7 @@ sub configure {
     $self->add_plugins(
         'InstallRelease',
         'Clean',
-    );
+    ) unless $conf->{fake_release};
 }
 
 
@@ -156,7 +157,7 @@ Dist::Zilla::PluginBundle::Author::DOHERTY - configure Dist::Zilla like DOHERTY
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -271,7 +272,7 @@ Mike Doherty <doherty@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Mike Doherty.
+This software is copyright (c) 2010 by Mike Doherty <doherty@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
